.. multi-scale-expansion documentation master file, created by
   sphinx-quickstart on Fri Apr 14 15:24:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to multi-scale-expansion's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   examples
   multi_scale_expansion

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
